# KillSwitch

Utility for managing blacklisted User Agent Strings.


## Installation

Add this line to your application's Gemfile:

```ruby
gem 'kill_switch'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install kill_switch


## Usage

1. In config/initializers create a file and define some rules

```ruby
ClientBlacklist.configure do |config|
  config.blacklist "1.03.00", "iOS", "iPhone OS 6.1", "iPhone4,1"
end

Format and optional params
  config.blacklist app_version, device_platform, <optional> device_os_version, <optional> device_model
Examples:
  config.blacklist "1.03.00", "iOS", "iPhone OS 6.1", "iPhone4,1"
  config.blacklist "1.03.00", "iOS", "iPhone OS 6.1"
  config.blacklist "1.03.00", "iOS", "iPhone4,1"
  config.blacklist "1.03.00", "iOS"
```

`device_os_version` and `device_model` are optional. If either are present, they will be matched

This class matches on depth first, meaning if `device_os_version` or `device_model` are present
in the rule definition, it will only match if the user agent also fully matches the criteria.

When defining rules, note presedence.
Given the user agent string 'BleachrClient/1.03.00 (iOS; iPhone OS 6.1; iPhone5,1)'
and the following rules
  config.blacklist "1.03.00", "iOS", "iPhone OS 6.1", "iPhone4,1"
  config.blacklist "1.03.00", "iOS"

The user agent **will not** be blacklisted because it does not match the first definition.
The first full definition overrides the more generic definition.


2. In the ApiController, add a hook to check for blacklisted user agents.

`before_action ClientBlacklist::BlacklistFilter`


3. Set-up for RSPEC tests

Add a helper method and config setting to `rails_helper.rb`.

```ruby
RSpec.configure do |config|
  
  ...

  config.before(:each, type: :controller) do
    set_user_agent
  end
end

def set_user_agent(user_agent = 'Client/0.00.01 (iOS; iPhone OS 6.1; iPhone4,1)')
  request.env["HTTP_USER_AGENT"] = user_agent
end
```

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake rspec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).


## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/livefront/kill_switch_gem. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](contributor-covenant.org) code of conduct.


## License

The gem is available as open source under the terms of the [MIT License](http://opensource.org/licenses/MIT).

